var gPlayerControlInterface;
var gConsole;

/**
 * Initialize the HTML select with the data provided into the frames.js file
 */
function initSerialFrames() {
    var frameid = document.getElementById("frameid");
    var frameraw = document.getElementById("frameraw");

    for (var i = 0 ; i < serialFrames.length ; i++) {
        var frame = serialFrames[i];

        if (frame.data !== undefined) {
            var option = createFrameOption("data-" + i, frame.name + " (" + JSON.stringify(frame.data) + ")");
            frameraw.appendChild(option);
        }
    }
    for (var i = 1 ; i <= 10 ; i++) {
        if (frame.data !== undefined) {
            var option = createFrameOption("id-" + i, "Frame " + i);
            frameid.appendChild(option);
        }
    }

}

/**
 * Create an HTML option element
 */
function createFrameOption(value, name) {
    var option = document.createElement("option");
    option.value = value;
    option.innerText = name
    return option;
}

/**
 * Send a serial frame
 * @param params is an object containing a 'data' or 'id' field
 */
function sendSerialFrame(params) {
    if (gPlayerControlInterface !== undefined) {
        gPlayerControlInterface.sendFrame(params)
            .then(function(value) {
                gConsole.log("Serial.sendFrame(" + JSON.stringify(params) + ") => " + JSON.stringify(value));
            })
            .catch(function(error) {
                gConsole.error("Error: Serial.sendFrame(" + JSON.stringify(params) + ") => " + JSON.stringify(error));
            });
    } else {
        gConsole.error("Error: Serial control interface not available");
    }
}

/**
 * Send the frame corresponding to the user selection
 */
function sendSelectedFrame() {
    var select = document.getElementById("frameselect");
    var value = select.options[select.selectedIndex].value;
    if (value !== undefined) {
        if (value.startsWith("id-")) {
            sendSerialFrame({ id: parseInt(value.substr(3)) });
        } else if (value.startsWith("data-")) {
            var idx = parseInt(value.substr(5));
            sendSerialFrame({ data: serialFrames[idx].data });
        }
    }
}

/**
 * Callback invoked when the page has been loaded
 */
function onPageLoaded() {
    gConsole = new OnScreenConsole();
    gConsole.initialize("console")

    // Initialize page
    initSerialFrames();

    // Get the video player object
    IDAL.getControlInterfaces()
        .then(function(iface) {
            gPlayerControlInterface = iface.serial;
        });
}

// Initialization at page startup
window.addEventListener("load", onPageLoaded);
